@@ -1,5 +1,5 @@
 package Crypt::HSM::Session;
-$Crypt::HSM::Session::VERSION = '0.017';
+$Crypt::HSM::Session::VERSION = '0.018';
 use strict;
 use warnings;
 
@@ -22,7 +22,7 @@ Crypt::HSM::Session - A PKCS11 session
 
 =head1 VERSION
 
-version 0.017
+version 0.018
 
 =head1 SYNOPSIS
 
@@ -71,7 +71,7 @@ Many functions will also take one or more mechanism specific additional argument
 
 =head2 create_object($attributes)
 
-Create an object with the given C<$attribute> hash. This returns a L<Crypt::HSM::Key|Crypt::HSM::Key> object.
+Create an object with the given C<$attribute> hash. This returns a L<Crypt::HSM::Object|Crypt::HSM::Object> object.
 
 =head2 decrypt($mechanism, $key, $ciphertext, ...)
 
@@ -79,7 +79,7 @@ Decrypt C<$ciphertext> with C<$mechanism> and C<$key>. This may take mechanism d
 
 =head2 derive_key($mechanism, $key, $attributes, ...)
 
-Derive a new key from C<$key>, using mechanism and setting C<$attributes> on it. This may take mechanism dependent additional arguments. This returns a L<Crypt::HSM::Key|Crypt::HSM::Key> object.
+Derive a new key from C<$key>, using mechanism and setting C<$attributes> on it. This may take mechanism dependent additional arguments. This returns a L<Crypt::HSM::Object|Crypt::HSM::Object> object.
 
 =head2 digest($mechanism, $key, $input, ...)
 
@@ -91,7 +91,7 @@ Encrypt C<$plaintext> with C<$mechanism> and C<$key>. This may take mechanism de
 
 =head2 find_objects($attributes)
 
-Find all objects that satisfy the given C<$attributes>. This returns a list of L<Crypt::HSM::Key|Crypt::HSM::Key> objects.
+Find all objects that satisfy the given C<$attributes>. This returns a list of L<Crypt::HSM::Object|Crypt::HSM::Object> objects.
 
 =head2 generate_key($mechanism, \%attributes)
 
@@ -133,11 +133,11 @@ This sets the length of a key, this can be useful when creating a C<'generic-sec
 
 =back
 
-Most of these have implementation-specific defaults. This returns a L<Crypt::HSM::Key|Crypt::HSM::Key> object.
+Most of these have implementation-specific defaults. This returns a L<Crypt::HSM::Object|Crypt::HSM::Object> object.
 
 =head2 generate_keypair($mechanism, \%public_attributes, \%private_attributes)
 
-This generates a key pair. The attributes for the public and private keys work similar to `generate_key`. This returns two L<Crypt::HSM::Key|Crypt::HSM::Key> objects.
+This generates a key pair. The attributes for the public and private keys work similar to `generate_key`. This returns two L<Crypt::HSM::Object|Crypt::HSM::Object> objects.
 
 =head2 generate_random($length)
 
@@ -201,7 +201,7 @@ Returns the slot identifier used for this session.
 
 =head2 unwrap_key($mechanism, $unwrap_key, $wrapped_key, $attributes, ...)
 
-This unwraps the key wrapped in the bytearray C<$wrapped_key> using C<mechanism> and key C<$unwrap_key>, setting C<$attributes> on the new key. This returns a L<Crypt::HSM::Key|Crypt::HSM::Key> object.
+This unwraps the key wrapped in the bytearray C<$wrapped_key> using C<mechanism> and key C<$unwrap_key>, setting C<$attributes> on the new key. This returns a L<Crypt::HSM::Object|Crypt::HSM::Object> object.
 
 =head2 verify($mechanism, $key, $data, $signature, ...)
 
